import {
  Accordion,
  AccordionDetails,
  AccordionSummary,
  Box,
  Button,
  Divider,
  IconButton,
  TextField,
  Typography,
} from '@mui/material'
import ChevronRightIcon from '@mui/icons-material/ChevronRight'
import ArrowDropDownIcon from '@mui/icons-material/ArrowDropDown'
import { useTheme, type Theme } from '@mui/material/styles'

interface Props {
  handleJoinClick: () => void
}

const Lobby = ({ handleJoinClick }: Props) => {
  const theme: Theme = useTheme()

  return (
    <Box
      sx={{
        backgroundColor: theme.palette.background.default,
        height: '100%',
        width: '100%',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
      }}
    >
      <Box
        width={'40%'}
        borderRadius={'20px'}
        sx={{ backgroundColor: '#262625', display: 'flex', flexDirection: 'column' }}
      >
        <Box sx={{ paddingY: '20px', backgroundColor: '#363739', borderRadius: '20px 20px 0 0' }}>
          <Typography
            variant='h4'
            sx={{
              color: theme.palette.common.white,
              textAlign: 'center',
              fontSize: '18px',
              fontWeight: '600',
            }}
          >
            Create or Join Room 👋
          </Typography>
        </Box>
        <Box padding={'30px'} display={'flex'} flexDirection={'column'}>
          <TextField
            id='username'
            label='Your Name'
            variant='outlined'
            sx={{
              backgroundColor: '#3f434a',
              borderRadius: '10px',
              color: theme.palette.common.white,
              marginBottom: '30px',
            }}
            inputProps={{
              style: { color: theme.palette.common.white, borderColor: theme.palette.common.white },
            }}
            InputLabelProps={{ style: { color: theme.palette.common.white } }}
          />
          <Box sx={{ display: 'flex', flexDirection: 'row', justifyContent: 'space-between' }}>
            <Box
              sx={{
                width: '50%',
                display: 'flex',
                flexDirection: 'row',
                alignItems: 'center',
                justifyContent: 'space-between',
              }}
            >
              <TextField
                id='room'
                label='Room Name'
                variant='outlined'
                sx={{
                  backgroundColor: '#3f434a',
                  borderRadius: '10px',
                  color: theme.palette.common.white,
                  width: '75%',
                }}
                inputProps={{ style: { color: theme.palette.common.white, borderColor: 'white' } }}
                InputLabelProps={{ style: { color: theme.palette.common.white } }}
              />
              <IconButton
                sx={{
                  backgroundColor: theme.palette.primary.main,
                  color: theme.palette.common.white,
                  width: '18%',
                  borderRadius: '10px',
                  height: '50px',
                }}
                aria-label='join room'
              >
                <ChevronRightIcon />
              </IconButton>
            </Box>
            <Divider
              orientation='vertical'
              variant='middle'
              sx={{ backgroundColor: theme.palette.common.white }}
              flexItem
            />
            <Box
              sx={{ display: 'flex', justifyContent: 'end', alignItems: 'center', width: '35%' }}
            >
              <Button
                sx={{
                  backgroundColor: theme.palette.primary.main,
                  color: theme.palette.common.white,
                  width: '90%',
                  borderRadius: '10px',
                  height: '50px',
                }}
                onClick={handleJoinClick}
              >
                Create Room
              </Button>
            </Box>
          </Box>
          <Box sx={{ marginTop: '30px' }}>
            <Accordion sx={{ backgroundColor: '#3f434a' }}>
              <AccordionSummary
                expandIcon={<ArrowDropDownIcon sx={{ color: theme.palette.common.white }} />}
                aria-controls='accord-content'
                id='accord-header'
              >
                <Typography
                  variant='h6'
                  sx={{ color: theme.palette.common.white, fontSize: '15px' }}
                >
                  Are you a differently-abled person? 🦸
                </Typography>
              </AccordionSummary>
              <AccordionDetails>
                <Box>sdsd</Box>
              </AccordionDetails>
            </Accordion>
          </Box>
        </Box>
      </Box>
    </Box>
  )
}

export default Lobby
